##  Creating a Custom KPI
  1. Go to Administration > KPIs, then choose New KPI.
  2. In the General Information step, specify the following:
     * Name and description
     * The SAP LeanIX use case this KPI supports
  3. Choose Next.
  4. In the Calculation Formula step, define how the KPI is calculated:
     * Choose the calculation method: absolute or percentage
     * Specify the aggregation rule: COUNT, SUM, or AVERAGE
     * Select the fact sheet type to include in the calculation
     * Define filters to select specific fact sheets
  5. Choose Next.
  6. In the Preview and Summary step, review your configuration and preview the current value.
  7. Choose Save.


The KPI is now available for use in dashboards and will be recalculated nightly.
![Screenshot of the KPI configuration wizard showing the calculation formula step with options for method, aggregation, and filters.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9fcfa2622aa04d5abf0c7624f889360b_LowRes.png)
KPI Configuration Wizard
